<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>DrawingPreferences</name>
    <message>
        <location filename="../DrawingPreferences.js" line="+43"/>
        <source>Drawing &amp;Preferences</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Preferencje ry&amp;sowania</translation>
    </message>
</context>
</TS>
